@@ -6,9 +6,10 @@ rm -f *.ppd
 ./Build distclean
 perl Build.PL
 ./Build install
-perldoc REST::Resource >  README
-perldoc REST::Request  >> README
-perldoc eg/parts.cgi   >> README
+perldoc REST::Resource		>  README
+perldoc REST::Request		>> README
+perldoc REST::RequestFast	>> README
+perldoc eg/cgi_server/parts.cgi	>> README
 ./Build dist
 ./Build ppmdist
 ./Build pardist
